add_tfd_var_to_ds: Add transformed variable to dataset

add_tfd_var_to_dsR Documentation

Add transformed variable to dataset

Description

add_tfd_var_to_ds() is an Add function that updates an object by adding data to that object. Specifically, this function implements an algorithm to add transformed variable to dataset. Function argument data_tb specifies the object to be updated. The function returns Data (a tibble).

Usage

add_tfd_var_to_ds(
  data_tb,
  depnt_var_nm_1L_chr,
  tfmn_1L_chr,
  depnt_var_max_val_1L_dbl = NULL
)

Arguments

data_tb

Data (a tibble)

depnt_var_nm_1L_chr

Dependent variable name (a character vector of length one)

tfmn_1L_chr

Transformation (a character vector of length one)

depnt_var_max_val_1L_dbl

Dependent variable maximum value (a double vector of length one), Default: NULL

Value

Data (a tibble)


ready4-dev/specific documentation built on Oct. 13, 2023, 7:54 a.m.