fit_ts_model_with_brm: Fit time series model with bayesian regression model

fit_ts_model_with_brmR Documentation

Fit time series model with bayesian regression model

Description

fit_ts_model_with_brm() is a Fit function that fits a model of a specified type to a dataset Specifically, this function implements an algorithm to fit time series model with bayesian regression model. The function returns Model list (a list of models).

Usage

fit_ts_model_with_brm(
  data_tb,
  depnt_var_nm_1L_chr,
  family_fn_1L_chr,
  id_var_nm_1L_chr,
  predr_vars_nms_chr,
  backend_1L_chr = getOption("brms.backend", "rstan"),
  control_ls = NULL,
  is_csnl_1L_lgl = F,
  iters_1L_int = 4000L,
  seed_1L_int = 1000L,
  prior_ls = NULL
)

Arguments

data_tb

Data (a tibble)

depnt_var_nm_1L_chr

Dependent variable name (a character vector of length one)

family_fn_1L_chr

Family function (a character vector of length one)

id_var_nm_1L_chr

Identity variable name (a character vector of length one)

predr_vars_nms_chr

Predictor variables names (a character vector)

backend_1L_chr

Backend (a character vector of length one), Default: getOption("brms.backend", "rstan")

control_ls

Control (a list), Default: NULL

is_csnl_1L_lgl

Is cross-sectional (a logical vector of length one), Default: F

iters_1L_int

Iterations (an integer vector of length one), Default: 4000

seed_1L_int

Seed (an integer vector of length one), Default: 1000

prior_ls

Prior (a list), Default: NULL

Value

Model list (a list of models)


ready4-dev/specific documentation built on Oct. 13, 2023, 7:54 a.m.