get_lngl_ttu_types: Get longitudinal transfer to utility algorithm types

get_lngl_ttu_typesR Documentation

Get longitudinal transfer to utility algorithm types

Description

get_lngl_ttu_types() is a Get function that retrieves a pre-existing data object from memory, local file system or online repository. Specifically, this function implements an algorithm to get longitudinal transfer to utility algorithm types. Function argument results_ls specifies the where to look for the required object. The function returns Model types (a character vector).

Usage

get_lngl_ttu_types(results_ls, collapse_1L_lgl = T)

Arguments

results_ls

Results (a list)

collapse_1L_lgl

Collapse (a logical vector of length one), Default: T

Value

Model types (a character vector)


ready4-dev/specific documentation built on Oct. 13, 2023, 7:54 a.m.