| get_mdl_cmprsns | R Documentation |
get_mdl_cmprsns() is a Get function that retrieves a pre-existing data object from memory, local file system or online repository. Specifically, this function implements an algorithm to get model comparisons. Function argument results_ls specifies the where to look for the required object. The function returns Model comparisons (an output object of multiple potential types).
get_mdl_cmprsns(
results_ls,
describe_1L_lgl = T,
mixed_1L_lgl = F,
as_list_1L_lgl = F
)
results_ls |
Results (a list) |
describe_1L_lgl |
Describe (a logical vector of length one), Default: T |
mixed_1L_lgl |
Mixed (a logical vector of length one), Default: F |
as_list_1L_lgl |
As list (a logical vector of length one), Default: F |
Model comparisons (an output object of multiple potential types)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.