| get_mdl_type_from_nm | R Documentation |
get_mdl_type_from_nm() is a Get function that retrieves a pre-existing data object from memory, local file system or online repository. Specifically, this function implements an algorithm to get model type from name. Function argument mdl_nm_1L_chr specifies the where to look for the required object. The function returns Model type (a character vector of length one).
get_mdl_type_from_nm(mdl_nm_1L_chr, mdl_types_lup = NULL)
mdl_nm_1L_chr |
Model name (a character vector of length one) |
mdl_types_lup |
Model types (a lookup table), Default: NULL |
Model type (a character vector of length one)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.