| get_nbr_of_predrs | R Documentation |
get_nbr_of_predrs() is a Get function that retrieves a pre-existing data object from memory, local file system or online repository. Specifically, this function implements an algorithm to get number of predictors. Function argument results_ls specifies the where to look for the required object. The function returns Number of predictors (an output object of multiple potential types).
get_nbr_of_predrs(results_ls, as_words_1L_lgl = T)
results_ls |
Results (a list) |
as_words_1L_lgl |
As words (a logical vector of length one), Default: T |
Number of predictors (an output object of multiple potential types)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.