get_popl_descvs: Get population descriptives

get_popl_descvsR Documentation

Get population descriptives

Description

get_popl_descvs() is a Get function that retrieves a pre-existing data object from memory, local file system or online repository. Specifically, this function implements an algorithm to get population descriptives. Function argument results_ls specifies the where to look for the required object. The function returns Population descriptives (a character vector of length one).

Usage

get_popl_descvs(results_ls)

Arguments

results_ls

Results (a list)

Value

Population descriptives (a character vector of length one)


ready4-dev/specific documentation built on Oct. 13, 2023, 7:54 a.m.