| get_signft_covars | R Documentation |
get_signft_covars() is a Get function that retrieves a pre-existing data object from memory, local file system or online repository. Specifically, this function implements an algorithm to get significant covariates. Function argument mdls_with_covars_smry_tb specifies the where to look for the required object. The function returns Signt covariates (a character vector).
get_signft_covars(
mdls_with_covars_smry_tb,
covar_var_nms_chr,
what_1L_chr = "any",
X_Ready4useDyad = NULL
)
mdls_with_covars_smry_tb |
Models with covariates summary (a tibble) |
covar_var_nms_chr |
Covariate variable names (a character vector) |
what_1L_chr |
What (a character vector of length one), Default: 'any' |
X_Ready4useDyad |
PARAM_DESCRIPTION, Default: NULL |
Signt covariates (a character vector)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.