| make_abstract_args_ls | R Documentation |
make_abstract_args_ls() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make abstract arguments list. The function returns Abstract arguments (a list).
make_abstract_args_ls(results_ls, fl_nm_1L_chr = "abstract.txt")
results_ls |
Results (a list) |
fl_nm_1L_chr |
File name (a character vector of length one), Default: 'abstract.txt' |
Abstract arguments (a list)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.