make_coi_text: Make conflict of interest text

make_coi_textR Documentation

Make conflict of interest text

Description

make_coi_text() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make conflict of interest text. The function returns Text (a character vector of length one).

Usage

make_coi_text(results_ls)

Arguments

results_ls

Results (a list)

Value

Text (a character vector of length one)


ready4-dev/specific documentation built on Oct. 13, 2023, 7:54 a.m.