make_csnl_example_predrs: Make cross-sectional example predictors

make_csnl_example_predrsR Documentation

Make cross-sectional example predictors

Description

make_csnl_example_predrs() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make cross-sectional example predictors. The function returns Predictors (a ready4 S3).

Usage

make_csnl_example_predrs()

Value

Predictors (a ready4 S3)


ready4-dev/specific documentation built on Oct. 13, 2023, 7:54 a.m.