make_funding_text: Make funding text

make_funding_textR Documentation

Make funding text

Description

make_funding_text() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make funding text. The function returns Text (a character vector of length one).

Usage

make_funding_text(results_ls)

Arguments

results_ls

Results (a list)

Value

Text (a character vector of length one)


ready4-dev/specific documentation built on Oct. 13, 2023, 7:54 a.m.