make_hlth_utl_and_predrs_ls: Make health utility and predictors list

make_hlth_utl_and_predrs_lsR Documentation

Make health utility and predictors list

Description

make_hlth_utl_and_predrs_ls() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make health utility and predictors list. The function returns Health utility and predictors (a list).

Usage

make_hlth_utl_and_predrs_ls(
  outp_smry_ls,
  descv_tbls_ls,
  nbr_of_digits_1L_int = 2L,
  old_nms_chr = NULL,
  new_nms_chr = NULL
)

Arguments

outp_smry_ls

Output summary (a list)

descv_tbls_ls

Descriptive tables (a list)

nbr_of_digits_1L_int

Number of digits (an integer vector of length one), Default: 2

old_nms_chr

Old names (a character vector), Default: NULL

new_nms_chr

New names (a character vector), Default: NULL

Value

Health utility and predictors (a list)


ready4-dev/specific documentation built on Oct. 13, 2023, 7:54 a.m.