make_incld_mdl_paths: Make included model paths

make_incld_mdl_pathsR Documentation

Make included model paths

Description

make_incld_mdl_paths() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make included model paths. The function returns Included model paths (a character vector).

Usage

make_incld_mdl_paths(outp_smry_ls)

Arguments

outp_smry_ls

Output summary (a list)

Value

Included model paths (a character vector)


ready4-dev/specific documentation built on Oct. 13, 2023, 7:54 a.m.