make_paths_to_ms_smry_plts_ls: Make paths to manuscript summary plots list

make_paths_to_ms_smry_plts_lsR Documentation

Make paths to manuscript summary plots list

Description

make_paths_to_ms_smry_plts_ls() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make paths to manuscript summary plots list. The function returns Paths to manuscript summary plots (a list).

Usage

make_paths_to_ms_smry_plts_ls(
  output_data_dir_1L_chr,
  outp_smry_ls,
  additional_paths_chr = "/dens_and_sctr.png"
)

Arguments

output_data_dir_1L_chr

Output data directory (a character vector of length one)

outp_smry_ls

Output summary (a list)

additional_paths_chr

Additional paths (a character vector), Default: '/dens_and_sctr.png'

Value

Paths to manuscript summary plots (a list)


ready4-dev/specific documentation built on Oct. 13, 2023, 7:54 a.m.