make_scaling_fctr_dbl: Make scaling factor double vector

make_scaling_fctr_dblR Documentation

Make scaling factor double vector

Description

make_scaling_fctr_dbl() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make scaling factor double vector. The function returns Scaling factor (a double vector).

Usage

make_scaling_fctr_dbl(outp_smry_ls)

Arguments

outp_smry_ls

Output summary (a list)

Value

Scaling factor (a double vector)


ready4-dev/specific documentation built on Oct. 13, 2023, 7:54 a.m.