plot_lnr_cmprsn: Plot linear comparison

plot_lnr_cmprsnR Documentation

Plot linear comparison

Description

plot_lnr_cmprsn() is a Plot function that plots data Specifically, this function implements an algorithm to plot linear comparison. The function is called for its side effects and does not return a value.

Usage

plot_lnr_cmprsn(
  data_tb,
  predn_ds_tb,
  predr_var_nm_1L_chr,
  predr_var_desc_1L_chr,
  depnt_var_nm_1L_chr = "utl_total_w",
  depnt_var_desc_1L_chr = "Total weighted utility score"
)

Arguments

data_tb

Data (a tibble)

predn_ds_tb

Prediction dataset (a tibble)

predr_var_nm_1L_chr

Predictor variable name (a character vector of length one)

predr_var_desc_1L_chr

Predictor variable description (a character vector of length one)

depnt_var_nm_1L_chr

Dependent variable name (a character vector of length one), Default: 'utl_total_w'

depnt_var_desc_1L_chr

Dependent variable description (a character vector of length one), Default: 'Total weighted utility score'


ready4-dev/specific documentation built on Oct. 13, 2023, 7:54 a.m.