| transform_depnt_var_nm | R Documentation |
transform_depnt_var_nm() is a Transform function that edits an object in such a way that core object attributes - e.g. shape, dimensions, elements, type - are altered. Specifically, this function implements an algorithm to transform dependent variable name. Function argument depnt_var_nm_1L_chr specifies the object to be updated. Argument tfmn_1L_chr provides the object to be updated. The function returns Transformed dependent variable name (a character vector of length one).
transform_depnt_var_nm(depnt_var_nm_1L_chr, tfmn_1L_chr = "NTF")
depnt_var_nm_1L_chr |
Dependent variable name (a character vector of length one) |
tfmn_1L_chr |
Transformation (a character vector of length one), Default: 'NTF' |
Transformed dependent variable name (a character vector of length one)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.