transform_rprt_lup: Transform report lookup table

transform_rprt_lupR Documentation

Transform report lookup table

Description

transform_rprt_lup() is a Transform function that edits an object in such a way that core object attributes - e.g. shape, dimensions, elements, type - are altered. Specifically, this function implements an algorithm to transform report lookup table. Function argument rprt_lup specifies the object to be updated. Argument add_suplry_rprt_1L_lgl provides the object to be updated. The function returns Report (a lookup table).

Usage

transform_rprt_lup(
  rprt_lup,
  add_suplry_rprt_1L_lgl = T,
  add_sharing_rprt_1L_lgl = F,
  start_at_int = NULL,
  reference_1L_int = NULL
)

Arguments

rprt_lup

Report (a lookup table)

add_suplry_rprt_1L_lgl

Add supplementary report (a logical vector of length one), Default: T

add_sharing_rprt_1L_lgl

Add sharing report (a logical vector of length one), Default: F

start_at_int

Start at (an integer vector), Default: NULL

reference_1L_int

Reference (an integer vector of length one), Default: NULL

Value

Report (a lookup table)


ready4-dev/specific documentation built on Oct. 13, 2023, 7:54 a.m.