| write_mdl_cmprsn | R Documentation |
write_mdl_cmprsn() is a Write function that writes a file to a specified local directory. Specifically, this function implements an algorithm to write model comparison. The function returns Model comparison (a list).
write_mdl_cmprsn(
scored_data_tb,
ds_smry_ls,
mdl_smry_ls,
output_data_dir_1L_chr,
consent_1L_chr = "",
consent_indcs_int = 1L,
depnt_var_max_val_1L_dbl = 0.99999,
depnt_var_min_val_1L_dbl = 1e-05,
options_chr = c("Y", "N"),
seed_1L_int = 1234
)
scored_data_tb |
Scored data (a tibble) |
ds_smry_ls |
Dataset summary (a list) |
mdl_smry_ls |
Model summary (a list) |
output_data_dir_1L_chr |
Output data directory (a character vector of length one) |
consent_1L_chr |
Consent (a character vector of length one), Default: ” |
consent_indcs_int |
Consent indices (an integer vector), Default: 1 |
depnt_var_max_val_1L_dbl |
Dependent variable maximum value (a double vector of length one), Default: 0.99999 |
depnt_var_min_val_1L_dbl |
Dependent variable minimum value (a double vector of length one), Default: 1e-05 |
options_chr |
Options (a character vector), Default: c("Y", "N") |
seed_1L_int |
Seed (an integer vector of length one), Default: 1234 |
Model comparison (a list)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.