| write_predr_cmprsn_outps | R Documentation |
write_predr_cmprsn_outps() is a Write function that writes a file to a specified local directory. Specifically, this function implements an algorithm to write predictor comparison outputs. The function returns Confirmed predictors (a tibble).
write_predr_cmprsn_outps(
data_tb,
path_to_write_to_1L_chr,
new_dir_nm_1L_chr = "B_Candidate_Predrs_Cmprsn",
consent_1L_chr = "",
consent_indcs_int = 1L,
depnt_var_min_val_1L_dbl = numeric(0),
depnt_var_nm_1L_chr = "utl_total_w",
candidate_predrs_chr,
max_nbr_of_boruta_mdl_runs_int = 300L,
options_chr = c("Y", "N")
)
data_tb |
Data (a tibble) |
path_to_write_to_1L_chr |
Path to write to (a character vector of length one) |
new_dir_nm_1L_chr |
New directory name (a character vector of length one), Default: 'B_Candidate_Predrs_Cmprsn' |
consent_1L_chr |
Consent (a character vector of length one), Default: ” |
consent_indcs_int |
Consent indices (an integer vector), Default: 1 |
depnt_var_min_val_1L_dbl |
Dependent variable minimum value (a double vector of length one), Default: numeric(0) |
depnt_var_nm_1L_chr |
Dependent variable name (a character vector of length one), Default: 'utl_total_w' |
candidate_predrs_chr |
Candidate predictors (a character vector) |
max_nbr_of_boruta_mdl_runs_int |
Maximum number of boruta model runs (an integer vector), Default: 300 |
options_chr |
Options (a character vector), Default: c("Y", "N") |
Confirmed predictors (a tibble)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.