| add_tfd_var_to_ds | R Documentation |
add_tfd_var_to_ds() is an Add function that updates an object by adding data to that object. Specifically, this function implements an algorithm to add transformed variable to dataset. Function argument data_tb specifies the object to be updated. The function returns Data (a tibble).
add_tfd_var_to_ds(
data_tb,
depnt_var_nm_1L_chr,
tfmn_1L_chr,
depnt_var_max_val_1L_dbl = NULL
)
data_tb |
Data (a tibble) |
depnt_var_nm_1L_chr |
Dependent variable name (a character vector of length one) |
tfmn_1L_chr |
Transformation (a character vector of length one) |
depnt_var_max_val_1L_dbl |
Dependent variable maximum value (a double vector of length one), Default: NULL |
Data (a tibble)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.