| get_lngl_ttu_types | R Documentation |
get_lngl_ttu_types() is a Get function that retrieves a pre-existing data object from memory, local file system or online repository. Specifically, this function implements an algorithm to get longitudinal transfer to utility algorithm types. Function argument results_ls specifies the where to look for the required object. The function returns Model types (a character vector).
get_lngl_ttu_types(results_ls, collapse_1L_lgl = T)
results_ls |
Results (a list) |
collapse_1L_lgl |
Collapse (a logical vector of length one), Default: T |
Model types (a character vector)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.