| make_csnl_example_predrs | R Documentation |
make_csnl_example_predrs() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make cross-sectional example predictors. The function returns Predictors (a ready4 S3).
make_csnl_example_predrs()
Predictors (a ready4 S3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.