| make_hlth_utl_and_predrs_ls | R Documentation |
make_hlth_utl_and_predrs_ls() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make health utility and predictors list. The function returns Health utility and predictors (a list).
make_hlth_utl_and_predrs_ls(
outp_smry_ls,
descv_tbls_ls,
nbr_of_digits_1L_int = 2L,
old_nms_chr = NULL,
new_nms_chr = NULL
)
outp_smry_ls |
Output summary (a list) |
descv_tbls_ls |
Descriptive tables (a list) |
nbr_of_digits_1L_int |
Number of digits (an integer vector of length one), Default: 2 |
old_nms_chr |
Old names (a character vector), Default: NULL |
new_nms_chr |
New names (a character vector), Default: NULL |
Health utility and predictors (a list)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.