| make_paths_to_ms_smry_plts_ls | R Documentation |
make_paths_to_ms_smry_plts_ls() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make paths to manuscript summary plots list. The function returns Paths to manuscript summary plots (a list).
make_paths_to_ms_smry_plts_ls(
output_data_dir_1L_chr,
outp_smry_ls,
additional_paths_chr = "/dens_and_sctr.png"
)
output_data_dir_1L_chr |
Output data directory (a character vector of length one) |
outp_smry_ls |
Output summary (a list) |
additional_paths_chr |
Additional paths (a character vector), Default: '/dens_and_sctr.png' |
Paths to manuscript summary plots (a list)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.