| make_scaling_fctr_dbl | R Documentation |
make_scaling_fctr_dbl() is a Make function that creates a new R object. Specifically, this function implements an algorithm to make scaling factor double vector. The function returns Scaling factor (a double vector).
make_scaling_fctr_dbl(outp_smry_ls)
outp_smry_ls |
Output summary (a list) |
Scaling factor (a double vector)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.