| plot_lnr_cmprsn | R Documentation |
plot_lnr_cmprsn() is a Plot function that plots data Specifically, this function implements an algorithm to plot linear comparison. The function is called for its side effects and does not return a value.
plot_lnr_cmprsn(
data_tb,
predn_ds_tb,
predr_var_nm_1L_chr,
predr_var_desc_1L_chr,
depnt_var_nm_1L_chr = "utl_total_w",
depnt_var_desc_1L_chr = "Total weighted utility score"
)
data_tb |
Data (a tibble) |
predn_ds_tb |
Prediction dataset (a tibble) |
predr_var_nm_1L_chr |
Predictor variable name (a character vector of length one) |
predr_var_desc_1L_chr |
Predictor variable description (a character vector of length one) |
depnt_var_nm_1L_chr |
Dependent variable name (a character vector of length one), Default: 'utl_total_w' |
depnt_var_desc_1L_chr |
Dependent variable description (a character vector of length one), Default: 'Total weighted utility score' |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.