| transform_rprt_lup | R Documentation |
transform_rprt_lup() is a Transform function that edits an object in such a way that core object attributes - e.g. shape, dimensions, elements, type - are altered. Specifically, this function implements an algorithm to transform report lookup table. Function argument rprt_lup specifies the object to be updated. Argument add_suplry_rprt_1L_lgl provides the object to be updated. The function returns Report (a lookup table).
transform_rprt_lup(
rprt_lup,
add_suplry_rprt_1L_lgl = T,
add_sharing_rprt_1L_lgl = F,
start_at_int = NULL,
reference_1L_int = NULL
)
rprt_lup |
Report (a lookup table) |
add_suplry_rprt_1L_lgl |
Add supplementary report (a logical vector of length one), Default: T |
add_sharing_rprt_1L_lgl |
Add sharing report (a logical vector of length one), Default: F |
start_at_int |
Start at (an integer vector), Default: NULL |
reference_1L_int |
Reference (an integer vector of length one), Default: NULL |
Report (a lookup table)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.